# Installation
- Require python >= 3.12
- using pip
    ```
    $ pip install cmk-active-check-maker
    ```
- using poetry
    ```
    $ poetry add cmk-active-check-maker
    ```


# Guide
- Require: using in global environment
- create new checkmk active check plugin template with command then fill the questions
    ```
    $ create-cmk-active-check
    ```
